A docassemble extension about baseball.

This is a new version, just as a test.

This is an even newer version, testing the twine upload process.

This is a newer version still, testing the new sdist process.

Verifying that the new sdist process still works.

Trying another push with a pyproject.toml.